@@ -13,6 +13,7 @@ from styler_rest_framework.config import defaults
 from styler_rest_framework.middlewares.fastapi import exception_middleware
 from styler_rest_framework.middlewares.fastapi.auth_middleware import add_auth_middleware
 from styler_rest_framework.logging.error_reporting import google_error_reporting_handler
+from styler_rest_framework.logging.logging_filter import EndpointFilter
 
 
 def api_error_reporting_handler(service=None):  # pragma: no coverage
@@ -50,6 +51,8 @@ def add_middlewares(app, error_handler=None, service=None, handle_exceptions_arg
         app, error_handler=error_handler, **handle_exceptions_args
     )
 
+    logging.getLogger("uvicorn.access").addFilter(EndpointFilter())
+
 
 def setup_validation_handler(
     app, validation_error_code=422, validation_code="validation_error"
@@ -63,7 +66,7 @@ def setup_validation_handler(
         locale = request.headers.get("Accept-Language", "ja")
         errors = {}
         for err in exc.errors():
-            field = ".".join(err["loc"][1:]) or "error"
+            field = ".".join([str(e) for e in err["loc"][1:]]) or "error"
             err_type = err["type"].replace(".", "_")
             errors[field] = message.get(
                 f"pydantic_validation.{err_type}", locale=locale, **err.get("ctx", {})
